from argparse import ArgumentParser
from jlp import get_launchpad, launchpadutils, logger
import os
from shutil import rmtree


def getMergeCount(branch, merge_type):
    """Returns the total number of outstanding merge requests for the given
    type."""
    count = 0
    # launchpadlib is not thread/process safe so we are creating launchpadlib
    # cache in /tmp per process which gets cleaned up at the end
    # see also lp:459418 and lp:1025153
    launchpad_cachedir = os.path.join('/tmp',
                                      str(os.getpid()),
                                      '.launchpadlib')
    lp_handle = get_launchpad(launchpadlib_dir=launchpad_cachedir)
    for b in branch:
        mps = launchpadutils.get_merge_proposals(lp_handle, b, [merge_type])
        logger.debug("[%s] merge proposals: %s" % (b, mps))
        logger.debug("count: %d" % (len(mps)))
        count += len(mps)
    rmtree(launchpad_cachedir, ignore_errors=True)
    return count


def getMergeProposals():
    parser = ArgumentParser(description="Return count of outstanding merge "
                            "proposals.")
    parser.add_argument("-t", "--merge_type", default="Approved",
                        help="Count only this type of merge proposals.")
    parser.add_argument("branch", nargs="+",
                        help="Branch to check merge count.")
    args = vars(parser.parse_args())

    return getMergeCount(**args)
