import os
import hashlib
from jlp import logger, get_config_option


class MergeProposalReview():
    _mp = None

    def __init__(self, mp):
        self._mp = mp

    @property
    def mp(self):
        """Merge proposal."""

        return self._mp

    def _get_hash(self):
        return hashlib.sha224(self.mp.web_link).hexdigest()

    def get_lockfile(self):
        return '{dir}/{hash}'.format(
            dir=get_config_option('launchpadlocks_dir'),
            hash=self._get_hash())

    def lock(self, job_name):
        locks_dir = get_config_option('launchpadlocks_dir')
        if not os.path.exists(locks_dir):
            os.makedirs(locks_dir)
        lockfile = open(self.get_lockfile(), 'w')
        lock_info = "{jenkins_job}\n{merge_proposal}\n"
        lock_info = lock_info.format(jenkins_job=job_name,
                                     merge_proposal=self.mp.web_link)
        lockfile.write(lock_info)
        lockfile.close()

    def unlock(self):
        try:
            os.remove(self.get_lockfile())
            return True
        except OSError as error:
            if error.errno == 2:
                logger.debug("mp lock doesn't exists. Ignoring this unlock.")
            return False

    def get_jenkins_job(self):
        if self.is_locked():
            lockfile = open(self.get_lockfile(), 'r')
            job_name = lockfile.readline().rstrip()
            return job_name
        else:
            return None

    def is_locked(self):
        return os.path.exists(self.get_lockfile())
